==> devextreme-21.1.1-alpha-21089-0329.tgz: package/cjs/ui/form/constants.js <==
/**
 * DevExtreme (cjs/ui/form/constants.js)
 * Version: 21.1.0 (build 21089-0329)
 * Build date: Tue Mar 30 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.FORM_VALIDATION_SUMMARY = exports.GROUP_COL_COUNT_ATTR = exports.GROUP_COL_COUNT_CLASS = exports.FIELD_ITEM_TAB_CLASS = exports.HIDDEN_LABEL_CLASS = exports.FORM_GROUP_WITH_CAPTION_CLASS = exports.FIELD_ITEM_CONTENT_HAS_TABS_CLASS = exports.FIELD_ITEM_CONTENT_HAS_GROUP_CLASS = exports.FORM_GROUP_CONTENT_CLASS = exports.ROOT_SIMPLE_ITEM_CLASS = exports.SINGLE_COLUMN_ITEM_CONTENT = exports.FIELD_BUTTON_ITEM_CLASS = exports.FIELD_EMPTY_ITEM_CLASS = exports.FIELD_ITEM_CONTENT_CLASS = exports.FIELD_ITEM_CONTENT_LOCATION_CLASS = exports.FIELD_ITEM_LABEL_CLASS = exports.FIELD_ITEM_LABEL_ALIGN_CLASS = exports.FIELD_ITEM_LABEL_LOCATION_CLASS = exports.LABEL_HORIZONTAL_ALIGNMENT_CLASS = exports.LABEL_VERTICAL_ALIGNMENT_CLASS = exports.FORM_LAYOUT_MANAGER_CLASS = exports.FIELD_ITEM_CONTENT_WRAPPER_CLASS = exports.FIELD_ITEM_HELP_TEXT_CLASS = exports.FIELD_ITEM_LABEL_CONTENT_CLASS = exports.FIELD_ITEM_LABEL_TEXT_CLASS = exports.FIELD_ITEM_REQUIRED_CLASS = exports.FIELD_ITEM_OPTIONAL_CLASS = exports.FIELD_ITEM_REQUIRED_MARK_CLASS = exports.FIELD_ITEM_OPTIONAL_MARK_CLASS = exports.LAYOUT_MANAGER_ONE_COLUMN = exports.FLEX_LAYOUT_CLASS = exports.FIELD_ITEM_CLASS = exports.FORM_FIELD_ITEM_COL_CLASS = exports.FORM_GROUP_CAPTION_CLASS = exports.FORM_GROUP_CLASS = exports.FORM_CLASS = void 0;
var FORM_CLASS = "dx-form";
exports.FORM_CLASS = FORM_CLASS;
var FORM_GROUP_CLASS = "dx-form-group";
exports.FORM_GROUP_CLASS = FORM_GROUP_CLASS;
var FORM_GROUP_CAPTION_CLASS = "dx-form-group-caption";
exports.FORM_GROUP_CAPTION_CLASS = FORM_GROUP_CAPTION_CLASS;
var FORM_FIELD_ITEM_COL_CLASS = "dx-col-";
exports.FORM_FIELD_ITEM_COL_CLASS = FORM_FIELD_ITEM_COL_CLASS;
var FIELD_ITEM_CLASS = "dx-field-item";
exports.FIELD_ITEM_CLASS = FIELD_ITEM_CLASS;
var FLEX_LAYOUT_CLASS = "dx-flex-layout";
exports.FLEX_LAYOUT_CLASS = FLEX_LAYOUT_CLASS;
var LAYOUT_MANAGER_ONE_COLUMN = "dx-layout-manager-one-col";
exports.LAYOUT_MANAGER_ONE_COLUMN = LAYOUT_MANAGER_ONE_COLUMN;
var FIELD_ITEM_OPTIONAL_MARK_CLASS = "dx-field-item-optional-mark";
exports.FIELD_ITEM_OPTIONAL_MARK_CLASS = FIELD_ITEM_OPTIONAL_MARK_CLASS;
var FIELD_ITEM_REQUIRED_MARK_CLASS = "dx-field-item-required-mark";
exports.FIELD_ITEM_REQUIRED_MARK_CLASS = FIELD_ITEM_REQUIRED_MARK_CLASS;
var FIELD_ITEM_OPTIONAL_CLASS = "dx-field-item-optional";
exports.FIELD_ITEM_OPTIONAL_CLASS = FIELD_ITEM_OPTIONAL_CLASS;
var FIELD_ITEM_REQUIRED_CLASS = "dx-field-item-required";
exports.FIELD_ITEM_REQUIRED_CLASS = FIELD_ITEM_REQUIRED_CLASS;
var FIELD_ITEM_LABEL_TEXT_CLASS = "dx-field-item-label-text";
exports.FIELD_ITEM_LABEL_TEXT_CLASS = FIELD_ITEM_LABEL_TEXT_CLASS;
var FIELD_ITEM_LABEL_CONTENT_CLASS = "dx-field-item-label-content";
exports.FIELD_ITEM_LABEL_CONTENT_CLASS = FIELD_ITEM_LABEL_CONTENT_CLASS;
var FIELD_ITEM_HELP_TEXT_CLASS = "dx-field-item-help-text";
exports.FIELD_ITEM_HELP_TEXT_CLASS = FIELD_ITEM_HELP_TEXT_CLASS;
var FIELD_ITEM_CONTENT_WRAPPER_CLASS = "dx-field-item-content-wrapper";
exports.FIELD_ITEM_CONTENT_WRAPPER_CLASS = FIELD_ITEM_CONTENT_WRAPPER_CLASS;
var FORM_LAYOUT_MANAGER_CLASS = "dx-layout-manager";
exports.FORM_LAYOUT_MANAGER_CLASS = FORM_LAYOUT_MANAGER_CLASS;
var LABEL_VERTICAL_ALIGNMENT_CLASS = "dx-label-v-align";
exports.LABEL_VERTICAL_ALIGNMENT_CLASS = LABEL_VERTICAL_ALIGNMENT_CLASS;
var LABEL_HORIZONTAL_ALIGNMENT_CLASS = "dx-label-h-align";
exports.LABEL_HORIZONTAL_ALIGNMENT_CLASS = LABEL_HORIZONTAL_ALIGNMENT_CLASS;
var FIELD_ITEM_LABEL_LOCATION_CLASS = "dx-field-item-label-location-";
exports.FIELD_ITEM_LABEL_LOCATION_CLASS = FIELD_ITEM_LABEL_LOCATION_CLASS;
var FIELD_ITEM_LABEL_ALIGN_CLASS = "dx-field-item-label-align";
exports.FIELD_ITEM_LABEL_ALIGN_CLASS = FIELD_ITEM_LABEL_ALIGN_CLASS;
var FIELD_ITEM_LABEL_CLASS = "dx-field-item-label";
exports.FIELD_ITEM_LABEL_CLASS = FIELD_ITEM_LABEL_CLASS;
var FIELD_ITEM_CONTENT_LOCATION_CLASS = "dx-field-item-content-location-";
exports.FIELD_ITEM_CONTENT_LOCATION_CLASS = FIELD_ITEM_CONTENT_LOCATION_CLASS;
var FIELD_ITEM_CONTENT_CLASS = "dx-field-item-content";
exports.FIELD_ITEM_CONTENT_CLASS = FIELD_ITEM_CONTENT_CLASS;
var FIELD_EMPTY_ITEM_CLASS = "dx-field-empty-item";
exports.FIELD_EMPTY_ITEM_CLASS = FIELD_EMPTY_ITEM_CLASS;
var FIELD_BUTTON_ITEM_CLASS = "dx-field-button-item";
exports.FIELD_BUTTON_ITEM_CLASS = FIELD_BUTTON_ITEM_CLASS;
var SINGLE_COLUMN_ITEM_CONTENT = "dx-single-column-item-content";
exports.SINGLE_COLUMN_ITEM_CONTENT = SINGLE_COLUMN_ITEM_CONTENT;
var ROOT_SIMPLE_ITEM_CLASS = "dx-root-simple-item";
exports.ROOT_SIMPLE_ITEM_CLASS = ROOT_SIMPLE_ITEM_CLASS;
var FORM_GROUP_CONTENT_CLASS = "dx-form-group-content";
exports.FORM_GROUP_CONTENT_CLASS = FORM_GROUP_CONTENT_CLASS;
var FIELD_ITEM_CONTENT_HAS_GROUP_CLASS = "dx-field-item-has-group";
exports.FIELD_ITEM_CONTENT_HAS_GROUP_CLASS = FIELD_ITEM_CONTENT_HAS_GROUP_CLASS;
var FIELD_ITEM_CONTENT_HAS_TABS_CLASS = "dx-field-item-has-tabs";
exports.FIELD_ITEM_CONTENT_HAS_TABS_CLASS = FIELD_ITEM_CONTENT_HAS_TABS_CLASS;
var FORM_GROUP_WITH_CAPTION_CLASS = "dx-form-group-with-caption";
exports.FORM_GROUP_WITH_CAPTION_CLASS = FORM_GROUP_WITH_CAPTION_CLASS;
var HIDDEN_LABEL_CLASS = "dx-layout-manager-hidden-label";
exports.HIDDEN_LABEL_CLASS = HIDDEN_LABEL_CLASS;
var FIELD_ITEM_TAB_CLASS = "dx-field-item-tab";
exports.FIELD_ITEM_TAB_CLASS = FIELD_ITEM_TAB_CLASS;
var GROUP_COL_COUNT_CLASS = "dx-group-colcount-";
exports.GROUP_COL_COUNT_CLASS = GROUP_COL_COUNT_CLASS;
var GROUP_COL_COUNT_ATTR = "group-col-count";
exports.GROUP_COL_COUNT_ATTR = GROUP_COL_COUNT_ATTR;
var FORM_VALIDATION_SUMMARY = "dx-form-validation-summary";
exports.FORM_VALIDATION_SUMMARY = FORM_VALIDATION_SUMMARY;

==> devextreme-21.2.1-alpha-21243-0310.tgz: package/cjs/ui/form/constants.js <==
/**
 * DevExtreme (cjs/ui/form/constants.js)
 * Version: 21.2.0 (build 21243-0310)
 * Build date: Tue Aug 31 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.SIMPLE_ITEM_TYPE = exports.FORM_UNDERLINED_CLASS = exports.FORM_VALIDATION_SUMMARY = exports.GROUP_COL_COUNT_ATTR = exports.GROUP_COL_COUNT_CLASS = exports.FIELD_ITEM_TAB_CLASS = exports.FORM_GROUP_WITH_CAPTION_CLASS = exports.FIELD_ITEM_CONTENT_HAS_TABS_CLASS = exports.FIELD_ITEM_CONTENT_HAS_GROUP_CLASS = exports.FORM_GROUP_CONTENT_CLASS = exports.ROOT_SIMPLE_ITEM_CLASS = exports.SINGLE_COLUMN_ITEM_CONTENT = exports.FIELD_ITEM_CONTENT_CLASS = exports.FIELD_ITEM_LABEL_CLASS = exports.FORM_LAYOUT_MANAGER_CLASS = exports.FIELD_ITEM_LABEL_CONTENT_CLASS = exports.LAYOUT_MANAGER_ONE_COLUMN = exports.FIELD_ITEM_CLASS = exports.FORM_FIELD_ITEM_COL_CLASS = exports.FORM_GROUP_CAPTION_CLASS = exports.FORM_GROUP_CLASS = exports.FORM_CLASS = exports.WIDGET_CLASS = void 0;
var WIDGET_CLASS = "dx-widget";
exports.WIDGET_CLASS = WIDGET_CLASS;
var FORM_CLASS = "dx-form";
exports.FORM_CLASS = FORM_CLASS;
var FORM_GROUP_CLASS = "dx-form-group";
exports.FORM_GROUP_CLASS = FORM_GROUP_CLASS;
var FORM_GROUP_CAPTION_CLASS = "dx-form-group-caption";
exports.FORM_GROUP_CAPTION_CLASS = FORM_GROUP_CAPTION_CLASS;
var FORM_FIELD_ITEM_COL_CLASS = "dx-col-";
exports.FORM_FIELD_ITEM_COL_CLASS = FORM_FIELD_ITEM_COL_CLASS;
var FIELD_ITEM_CLASS = "dx-field-item";
exports.FIELD_ITEM_CLASS = FIELD_ITEM_CLASS;
var LAYOUT_MANAGER_ONE_COLUMN = "dx-layout-manager-one-col";
exports.LAYOUT_MANAGER_ONE_COLUMN = LAYOUT_MANAGER_ONE_COLUMN;
var FIELD_ITEM_LABEL_CONTENT_CLASS = "dx-field-item-label-content";
exports.FIELD_ITEM_LABEL_CONTENT_CLASS = FIELD_ITEM_LABEL_CONTENT_CLASS;
var FORM_LAYOUT_MANAGER_CLASS = "dx-layout-manager";
exports.FORM_LAYOUT_MANAGER_CLASS = FORM_LAYOUT_MANAGER_CLASS;
var FIELD_ITEM_LABEL_CLASS = "dx-field-item-label";
exports.FIELD_ITEM_LABEL_CLASS = FIELD_ITEM_LABEL_CLASS;
var FIELD_ITEM_CONTENT_CLASS = "dx-field-item-content";
exports.FIELD_ITEM_CONTENT_CLASS = FIELD_ITEM_CONTENT_CLASS;
var SINGLE_COLUMN_ITEM_CONTENT = "dx-single-column-item-content";
exports.SINGLE_COLUMN_ITEM_CONTENT = SINGLE_COLUMN_ITEM_CONTENT;
var ROOT_SIMPLE_ITEM_CLASS = "dx-root-simple-item";
exports.ROOT_SIMPLE_ITEM_CLASS = ROOT_SIMPLE_ITEM_CLASS;
var FORM_GROUP_CONTENT_CLASS = "dx-form-group-content";
exports.FORM_GROUP_CONTENT_CLASS = FORM_GROUP_CONTENT_CLASS;
var FIELD_ITEM_CONTENT_HAS_GROUP_CLASS = "dx-field-item-has-group";
exports.FIELD_ITEM_CONTENT_HAS_GROUP_CLASS = FIELD_ITEM_CONTENT_HAS_GROUP_CLASS;
var FIELD_ITEM_CONTENT_HAS_TABS_CLASS = "dx-field-item-has-tabs";
exports.FIELD_ITEM_CONTENT_HAS_TABS_CLASS = FIELD_ITEM_CONTENT_HAS_TABS_CLASS;
var FORM_GROUP_WITH_CAPTION_CLASS = "dx-form-group-with-caption";
exports.FORM_GROUP_WITH_CAPTION_CLASS = FORM_GROUP_WITH_CAPTION_CLASS;
var FIELD_ITEM_TAB_CLASS = "dx-field-item-tab";
exports.FIELD_ITEM_TAB_CLASS = FIELD_ITEM_TAB_CLASS;
var GROUP_COL_COUNT_CLASS = "dx-group-colcount-";
exports.GROUP_COL_COUNT_CLASS = GROUP_COL_COUNT_CLASS;
var GROUP_COL_COUNT_ATTR = "group-col-count";
exports.GROUP_COL_COUNT_ATTR = GROUP_COL_COUNT_ATTR;
var FORM_VALIDATION_SUMMARY = "dx-form-validation-summary";
exports.FORM_VALIDATION_SUMMARY = FORM_VALIDATION_SUMMARY;
var FORM_UNDERLINED_CLASS = "dx-form-styling-mode-underlined";
exports.FORM_UNDERLINED_CLASS = FORM_UNDERLINED_CLASS;
var SIMPLE_ITEM_TYPE = "simple";
exports.SIMPLE_ITEM_TYPE = SIMPLE_ITEM_TYPE;
